==> haskell-first-class-families-0.8.0.1-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-first-class-families.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 first-class-families
version:              0.8.0.1
visibility:           public
id:                   first-class-families-0.8.0.1-AHDo4MyKe8i9FepLL9znpF
key:                  first-class-families-0.8.0.1-AHDo4MyKe8i9FepLL9znpF
license:              MIT
copyright:            2018 Li-yao Xia
maintainer:           lysxia@gmail.com
author:               Li-yao Xia
homepage:             https://github.com/Lysxia/first-class-families#readme
synopsis:             First-class type families
description:
    A library for type-level programming.

    See README.

category:             Other
abi:                  179fb957d24459b9a1c2edf10f8d4152
exposed:              True
exposed-modules:
    Fcf Fcf.Class.Bifunctor Fcf.Class.Foldable Fcf.Class.Functor
    Fcf.Class.Monoid Fcf.Class.Monoid.Types Fcf.Class.Ord Fcf.Classes
    Fcf.Combinators Fcf.Core Fcf.Data.Bool Fcf.Data.Common
    Fcf.Data.Function Fcf.Data.List Fcf.Data.Nat Fcf.Data.Symbol
    Fcf.Utils

import-dirs:          /usr/lib/ghc-9.0.1/site-local/first-class-families-0.8.0.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/first-class-families-0.8.0.1
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/first-class-families-0.8.0.1

hs-libraries:         HSfirst-class-families-0.8.0.1-AHDo4MyKe8i9FepLL9znpF
depends:              base-4.15.0.0
haddock-interfaces:
    /usr/share/doc/haskell-first-class-families/html/first-class-families.haddock

haddock-html:         /usr/share/doc/haskell-first-class-families/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-first-class-families-0.8.0.1-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-first-class-families.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 first-class-families
version:              0.8.0.1
visibility:           public
id:                   first-class-families-0.8.0.1-baUR2cqZ6a8mZ6NW1ztpX
key:                  first-class-families-0.8.0.1-baUR2cqZ6a8mZ6NW1ztpX
license:              MIT
copyright:            2018 Li-yao Xia
maintainer:           lysxia@gmail.com
author:               Li-yao Xia
homepage:             https://github.com/Lysxia/first-class-families#readme
synopsis:             First-class type families
description:
    A library for type-level programming.

    See README.

category:             Other
abi:                  85a5893e76863601c951da0874b6dfff
exposed:              True
exposed-modules:
    Fcf Fcf.Class.Bifunctor Fcf.Class.Foldable Fcf.Class.Functor
    Fcf.Class.Monoid Fcf.Class.Monoid.Types Fcf.Class.Ord Fcf.Classes
    Fcf.Combinators Fcf.Core Fcf.Data.Bool Fcf.Data.Common
    Fcf.Data.Function Fcf.Data.List Fcf.Data.Nat Fcf.Data.Symbol
    Fcf.Utils

import-dirs:          /usr/lib/ghc-9.0.2/site-local/first-class-families-0.8.0.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/first-class-families-0.8.0.1
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.2/first-class-families-0.8.0.1

hs-libraries:         HSfirst-class-families-0.8.0.1-baUR2cqZ6a8mZ6NW1ztpX
depends:              base-4.15.1.0
haddock-interfaces:
    /usr/share/doc/haskell-first-class-families/html/first-class-families.haddock

haddock-html:         /usr/share/doc/haskell-first-class-families/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
